==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/outputs/ChannelEncoderSettingsVideoDescriptionCodecSettings.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property frameCaptureSettings Frame capture settings. See Frame Capture Settings for more details.
 * @property h264Settings H264 settings. See H264 Settings for more details.
 * @property h265Settings
 */
public data class ChannelEncoderSettingsVideoDescriptionCodecSettings(
    public val frameCaptureSettings:
    ChannelEncoderSettingsVideoDescriptionCodecSettingsFrameCaptureSettings? = null,
    public val h264Settings: ChannelEncoderSettingsVideoDescriptionCodecSettingsH264Settings? = null,
    public val h265Settings: ChannelEncoderSettingsVideoDescriptionCodecSettingsH265Settings? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.medialive.outputs.ChannelEncoderSettingsVideoDescriptionCodecSettings):
            ChannelEncoderSettingsVideoDescriptionCodecSettings =
            ChannelEncoderSettingsVideoDescriptionCodecSettings(
                frameCaptureSettings = javaType.frameCaptureSettings().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.medialive.kotlin.outputs.ChannelEncoderSettingsVideoDescriptionCodecSettingsFrameCaptureSettings.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                h264Settings = javaType.h264Settings().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.medialive.kotlin.outputs.ChannelEncoderSettingsVideoDescriptionCodecSettingsH264Settings.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                h265Settings = javaType.h265Settings().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.medialive.kotlin.outputs.ChannelEncoderSettingsVideoDescriptionCodecSettingsH265Settings.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/outputs/ChannelEncoderSettingsVideoDescriptionCodecSettings.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property frameCaptureSettings Frame capture settings. See Frame Capture Settings for more details.
 * @property h264Settings H264 settings. See H264 Settings for more details.
 * @property h265Settings
 */
public data class ChannelEncoderSettingsVideoDescriptionCodecSettings(
    public val frameCaptureSettings: ChannelEncoderSettingsVideoDescriptionCodecSettingsFrameCaptureSettings? = null,
    public val h264Settings: ChannelEncoderSettingsVideoDescriptionCodecSettingsH264Settings? = null,
    public val h265Settings: ChannelEncoderSettingsVideoDescriptionCodecSettingsH265Settings? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.medialive.outputs.ChannelEncoderSettingsVideoDescriptionCodecSettings): ChannelEncoderSettingsVideoDescriptionCodecSettings =
            ChannelEncoderSettingsVideoDescriptionCodecSettings(
                frameCaptureSettings = javaType.frameCaptureSettings().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.medialive.kotlin.outputs.ChannelEncoderSettingsVideoDescriptionCodecSettingsFrameCaptureSettings.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                h264Settings = javaType.h264Settings().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.medialive.kotlin.outputs.ChannelEncoderSettingsVideoDescriptionCodecSettingsH264Settings.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                h265Settings = javaType.h265Settings().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.medialive.kotlin.outputs.ChannelEncoderSettingsVideoDescriptionCodecSettingsH265Settings.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}
